/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSlice.h"
#include "HvControlVar.h"
#include "HvControlSystem.h"
#include "HvControlIf.h"
#include "HvControlCast.h"
#include "HvSignalBiquad.h"
#include "HvSignalLine.h"
#include "HvControlBinop.h"
#include "HvSignalVar.h"
#include "HvMath.h"
#include "HvControlUnop.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_dsN8pkgu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JADpV1aH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kvGWOCty_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1aBWMhMN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_uw5dsosA_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_g9SHf82X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wf06aHRM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_yAofSMS7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gf4T7K3Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Co8et8An_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5PQR4DpW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f2VD6ZHu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a45QNF6u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MmgdZZyH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qM7uK6dh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QY2LWqjS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ttS6ImW3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lGWr1c2I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_H7e0UDOf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sqMZ2guP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_j4mxw0yr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rNzNdQ8N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xYeGN1K3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_apID8Na3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e9J7bY1U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_emmsuAKO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3tZPJrph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nVclHjLz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1WO6phaX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NoPA3ptx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_d0powlEg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_71BrfrCC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_W6CXKOiK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ac6NULHu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IGsBLe5f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kr7Ap6Ng_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ov3JTbxl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nrsdHJiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qkgF3dHh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YfFyFz2C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TyUENvTE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iX8uto0D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W87zfquI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_S0a6yJht_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wb5y8Vaq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qnQMdcqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uiNK9jks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yW57TctG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z2kBgesx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_331w1JAv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r1Xui1BJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oSy4fS3Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3DPqSU0P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iaqoXGhL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8L6MRkm5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Yj5eN3LR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5HMUKueZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hDY4GOAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wrWNWI7T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yQxHJvHr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t5S5bJb4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AJ5RlONn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vfz3sBUA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q1m85ME4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bSOIsNPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W7kJA1l9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pWj8c71W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rFezQiMy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f1DbYlzY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WZbGiNcF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VnbqacwS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vZBDpukt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_etEEQCzp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sbmwefdI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WLKBPtO8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UzvBgY0O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jDpKHe6X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_zjFRVEfU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_4rctmv0a_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_nvoVxnqz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_K1Pp0HtM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hNrWwet9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_qPNfG8lF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_E9qgoYbl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bMIl5PfJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NO3Yao07_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ut8h9SwG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_KGd4b4xr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HBBtyO8s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Fv34fGcF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_nWflMqg2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_NWbfFNKU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_x3LUnzeW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_DK4Ke1Sb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ib5dNJgM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TPz8fMB7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sqOcqUgV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AZfEWJfR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FKmgDO4l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UngnOGwE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Te1C8iMa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_nnQNrWlU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RKxsEXp5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rJEkH8xo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yjS1eOsM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_niiCQMAw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WsPQ7bYD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_RC6glNRa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_p7ehRLb6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UbKDGOMp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WUC1RUoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Uqm0Cyrg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0ykKmFna_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1dIvgceH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZJW8Yi5z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mnXszDBr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Dh5MAKq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6Tf7xrse_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FQ8p69K5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z07BMeXo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KBLdL1xI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ij7lfmdn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MdLD9Ptp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7BGFeYBq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_F3TGriMZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_enNXzGjb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0eZO9AR4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CoDeZ2rp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_3Hx28NQx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_HdNGBgVb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_33rwzdS2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N8X8yzaO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LLMJqa2G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YjgcDy7q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N5jnc89H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PARXzEyA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7VDeuzKr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_56FyIYmw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BLJ2Ru7z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GbulahXl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6sUokRvw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F18irUFI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RFZDwSfu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P25apAAR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FbEEMQRV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0ODhCxy7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JVIhAMxE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5TsdAeJS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PNqmJ4Fz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YdsZlQ8j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O2xORRTk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zKMhMd4L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n9ZTaP6E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XozhnokY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KEqaOK15_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9Oyr6eKj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cn3zdHj9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_r7gN6QDo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_lypwa6Y7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FeSosP2N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fhMh6Y6V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_h6hTDmfL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s3ge6ohp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JtIKqRTC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2eBvqV8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_OPmFSFXx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IOTd570B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BcPDH0Qa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1kQLf2NH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IkhPHXpA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aXUv7mOd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jdf2ETPe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G41EKEDu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GZeLxtxa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2o6xyIAP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zec8Z3HH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CrZRwEdo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XmbCOdlB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GW3wWIDC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mm3kHydS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_QVQRTrD3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_WZwZ5Uzy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_j3sOga0r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hzB6KAn0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tcGdc2UQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VPmkB56d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HgXN8QTh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HfNFMBTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kxOQ41OI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OKu7lXxe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_21hgzEDD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1OhPZ55c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iuXdoK12_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KuiEuRjc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mw5sswZO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2fIqKcAT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kUIWcMxl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jEqyrcM4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_68SmcS08_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RXwBV7di_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0CxSuwkH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Fkfi1nQ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BtF9vtSc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CJd2suN5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ruc1xKEH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UcZD0oZ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r7SZ1GKx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ls5uWwR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_t1hijasF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cqH97wRI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kstgPsYC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B9UkE6l3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zDlFAHxi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sNnqV8QB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_07OTzmJD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_pTWhHgJR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HzdUFozX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c7ElLOaA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QFSSDvYY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lMMvLqKc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wzAj7jhj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CXsN8PNP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6BUc22ld_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lWvAI4JD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qolZKtl7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kl9OfRsD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_16PfvYlA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DO9BKUj1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JWLu63nu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yhMWdz8l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DRsrN7z7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4hYxRLi3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xbfRqYIB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_F0lcTAyr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Wlp6iXWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eblvbmvP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N0J0SCzx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_lVrwpXOd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_gLmsyqG5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_5LMsBUA7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4McVhf0f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WPHyYCDF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_989GPrnl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_57TlineR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8DxI5GUE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qu4S5WVO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W5jrbI5F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tel9uz70_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JklfyOO1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MfeLWJbe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_js7wLJby_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0trlCbVZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lxNGbbc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yb6X6oph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_koUdFRSo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M7VRQEEd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9QdQ79aQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nujA9Vhr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O08wpw8R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ayZjoHKE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lklbC5fa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wIiluudP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DLtdlt7f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_glGHbvMc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z4oCwVhg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_fqQJ1CSm_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_xOYwOo8d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KidvNyaD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Hc03UzDT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gFZafOdl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_W4PTZWYJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7fk3U9T6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GBckknnh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7ctSDmxU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JuLDjXzs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AwAGOPbw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AnNT5wPM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pXT6eOi5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hhtACbFR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8uwFjaIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bq3ughep_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Rt7TjMTn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rxHDCNB1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YkHx87AN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZT4uV8Y2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ddhTF2nL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WYbNvdgf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Py3blVey_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xbTiHavL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RAYi1MUP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9DkiBzL8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_o2wbwhxv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SKMtx35j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_q0en241i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MLibaInc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0Wa8WW84_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UOVGdAPN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vgnSckwy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kCYQKkhk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tfpUPA6N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yX4uMiYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YMbltdkp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cVOZydDw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0F9BbzjS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3f6Pb8fB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8xdoIce8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_s2NbjQXs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2AaIk6oj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Boj75aoH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eF29l7OF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CqX6ZbIG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PpIQ8Jx1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Mq8ksIPr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1t4jduV1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QTOQgIER_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1MklJSB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0fOC3rn1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_N5xyGVUl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HiMeP1SV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ycpGkJJM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O1GuoVF4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lxDFv0n3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ABttLuNj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mD9Vep9Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3WhPqvkp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C24kizb4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jrqoj0Xf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XyW3LIt5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PjVmlBnD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yjuo7DLt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PaAM7Cj1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gqfIyji9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vxc37eMM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v7gazb9g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_slYsI4D7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zTBO4QG3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jiFdvvUz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QQD0zvM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_XqaMtaaH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TvWtR1MO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_aEJYfduj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fn6yizAB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_aulUrHby_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zExoFbLX_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_pMoz4XKd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wBWLGulE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_WTJ4cPdd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_35b9Im70_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_xbpLVNjP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aak4CMLg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_z9kPpqqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Iw8G4ART_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_qKRwxHPa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4WK0mqLM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_HhJhNPXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Se8ae0ky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P8lpwRy4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qHQGikCN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0WvwETIu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FLgVqXgF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mKhdWlKz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_gzqnlN7a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_iu6oM3QX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wRjnWGm8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sgUxyd4a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rgFGUHI4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kb6XA1Wt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p2tYIZ1R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_p0de4D55_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_IM2WReEr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8iM2kOm6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V1fltldE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lo27Kg3b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9eWDhaLu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EfOZpjwr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4bHbXLaQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jHbW07hv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SWYmjATR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6gMrCr4w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TolrXJzL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R70Zapxt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BO4IGdXG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VyufPNEE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RQJI7Lus_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YqzCSnBi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Zh3y56Fd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tkggtXxX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bAxiRovL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BF9BCsAf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CIq7zeNC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VTHTBtgz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_G5Jn0DFQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gIgN5Geh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_meCjBfHS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QO2u9eel_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ieS5lLFC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DsCfbAwS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XcD3cal7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V1y7oiOL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VUtT2w2i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yZBXIPVt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bpmz1gwD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_H8fXwPqG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9T5iytud_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_503zjIsY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c2cuyYIw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W3PHzd3s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AirlDwlb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5ihYrVz9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v331Mt8x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3K5fVUhg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7TiQXOnN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q3VBFUUM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NS1pdeRZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_auWwTonf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g0pagqdf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RNSHYlB0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BZyK8ojP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Kmy4AW44_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_7UUXylwF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xw5ZJR0P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SApvVf7s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oyGNeEZf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OPWAlESW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mITVhGNK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ITG29NwT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_DhoL365f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fh2MiVvX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yRSpgA8J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8s17cltr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kIKoZz3P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tfgT9QUO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hLaM5Prh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YZHd8BwN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6yOwNvNS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pZVINLc5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_gCvuXMqq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UFWi8QIC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_8JvfzCZ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JEZRepEm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1YpFw4H0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_XthXLilf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GZdanwP8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_6OSjkJLy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UqXZ4aEv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ujfdt8wO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7NfDegZ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SjzUgJGo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DCnPnmYP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WJiu4BV5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bBeTpKOT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5wz3Ptf5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iNroQELg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tRrkvROi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t9Sgx8LZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OBoTch4C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_exiKbq7F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eRwZV3zT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DtQHPy9c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wx8KA5nz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C2eBVYLf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BuSiujEN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hcpVi1mD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NsMfosMP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WEXBTTy8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kr3KL4yg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Fw2BLTyn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RSUubSPI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_MS5LYURr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_WTvOqKdt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_72qgDGx9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oe5WCQBA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9JmKIBL2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z11vtAK5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kcTqbeuc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_aGmsWD4S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_7JnfDOAL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gxXIw6Ft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eWvEeciI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xBQ54wf7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kXMEpoNv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zeI0YxN4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bZxtUmvi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N5Ry2SR3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vYOtyo3t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7RckqJB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5bbrmsS1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j2UtQ1as_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NpMcn6b3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xJvvB3Oo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G1fAxiTd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2r2OTeCz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q1hqQk25_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xiwsHefm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vzw5CR0U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_awQgZzb1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yW3Vyfsg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2Gz4Va0h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_kVGgyJ2d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_5uxrc3D1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fAqlrclp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MqQA2J7Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2OlfAyLm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JvRDfOQ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_geL4CgxF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BLV5nMhK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_avBOLBh0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vdOSbLl3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2m6ciMGj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YLCs2jlz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wcO2ai0P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cyL6EpDN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cNPFHER9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VnZ8UJHi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mNUWWZOH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8qcCMti2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hhJfxl6T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qqUa9Gtr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2VATFCD5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_USX1JnQG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oY70DIyU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gFkaAWYA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HXZusjfJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1HZJ3plV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AvLrJvYP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NRv8x9Cs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WXZBWiDm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CynyOav2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_0GiB36YJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_4jdAYLIb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CDOUGRqt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IpR81aCP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fAS4vuX8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zi8QLL5u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gQ5uc0So_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hcyvxBdi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3LVxDxek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NSK7JRC8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ab1MBNp2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z9ikRXFn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ivJUJaQ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ecvRDOvq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wSsM5OnB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JYxt0HWn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sztrVgAF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9wifXj20_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wnXrQNXa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3HwgGvPt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CxZB78YB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FL9dNFWY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_E98oWkT5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hK32FfeX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_61aDsS7l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JuQYGT0G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6EXhVNgR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CTK1nFOm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Hj8M30AB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_NeF5E0XD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Nmbe8yW0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KZTT3m08_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ekk0F6qf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7vxng0Me_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mdVnO129_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_j8asidhY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9jTFKy0i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ttvWNK5K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yNG4WYD5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PWdMmHzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XkfBpn8X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ss85hQBr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_e64Qx61G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LL8CZACV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lutEfvGS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xpos8E3d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ah7KPUEQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_61QTNAwo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qiwl3uw7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_6dljYM9J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dismy5a8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_INBWazm2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_I4t9GnMK_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_26RVCf28;
  SignalLine sLine_KyVLa1UB;
  SignalLine sLine_7nRYMCXn;
  SignalLine sLine_YGe39g7z;
  SignalLine sLine_9pQcRCGk;
  SignalBiquad sBiquad_s_EplGjzsd;
  SignalLine sLine_Fp9h5P4u;
  SignalLine sLine_vOIdAb0w;
  SignalLine sLine_uQUaTdyF;
  SignalLine sLine_CJZa2lb7;
  SignalBiquad sBiquad_s_xi38GoFM;
  SignalLine sLine_u1zEhbnB;
  SignalLine sLine_ypbWiiaM;
  SignalLine sLine_bWKx1Kb5;
  SignalLine sLine_EoWDm78S;
  SignalLine sLine_5q0WqqtD;
  SignalBiquad sBiquad_s_EIDJ9JG5;
  SignalLine sLine_3avMmArf;
  SignalLine sLine_LpFBQGgW;
  SignalLine sLine_mJiwoo2r;
  SignalLine sLine_eNrooVM3;
  SignalLine sLine_hOZtJvAw;
  SignalBiquad sBiquad_s_sxZPvPz9;
  SignalLine sLine_5uzwBRqX;
  SignalLine sLine_O02kYo6Y;
  SignalLine sLine_BbZoOUuV;
  SignalLine sLine_BszWr8sb;
  SignalBiquad sBiquad_s_1lqnmFQd;
  SignalLine sLine_n3i9fv4Z;
  SignalLine sLine_lHdEctmj;
  SignalLine sLine_uBmcKOCS;
  SignalLine sLine_00CE6qrS;
  SignalLine sLine_I9inOEZZ;
  SignalBiquad sBiquad_s_fVVEeYHk;
  ControlVar cVar_dsN8pkgu;
  ControlVar cVar_JADpV1aH;
  ControlVar cVar_kvGWOCty;
  ControlVar cVar_1aBWMhMN;
  ControlSlice cSlice_g9SHf82X;
  ControlVar cVar_wf06aHRM;
  ControlVar cVar_gf4T7K3Q;
  ControlIf cIf_Co8et8An;
  ControlIf cIf_5PQR4DpW;
  ControlBinop cBinop_a45QNF6u;
  ControlBinop cBinop_MmgdZZyH;
  ControlBinop cBinop_ttS6ImW3;
  ControlBinop cBinop_lGWr1c2I;
  ControlBinop cBinop_sqMZ2guP;
  ControlIf cIf_j4mxw0yr;
  ControlBinop cBinop_rNzNdQ8N;
  ControlBinop cBinop_xYeGN1K3;
  ControlBinop cBinop_e9J7bY1U;
  ControlBinop cBinop_emmsuAKO;
  ControlBinop cBinop_3tZPJrph;
  ControlVar cVar_71BrfrCC;
  ControlIf cIf_W6CXKOiK;
  ControlIf cIf_ac6NULHu;
  ControlBinop cBinop_Kr7Ap6Ng;
  ControlBinop cBinop_Ov3JTbxl;
  ControlBinop cBinop_YfFyFz2C;
  ControlBinop cBinop_TyUENvTE;
  ControlBinop cBinop_W87zfquI;
  ControlIf cIf_S0a6yJht;
  ControlBinop cBinop_Wb5y8Vaq;
  ControlBinop cBinop_qnQMdcqN;
  ControlBinop cBinop_yW57TctG;
  ControlBinop cBinop_Z2kBgesx;
  ControlBinop cBinop_331w1JAv;
  ControlVar cVar_8L6MRkm5;
  ControlIf cIf_Yj5eN3LR;
  ControlIf cIf_5HMUKueZ;
  ControlBinop cBinop_wrWNWI7T;
  ControlBinop cBinop_yQxHJvHr;
  ControlBinop cBinop_Vfz3sBUA;
  ControlBinop cBinop_q1m85ME4;
  ControlBinop cBinop_W7kJA1l9;
  ControlIf cIf_pWj8c71W;
  ControlBinop cBinop_rFezQiMy;
  ControlBinop cBinop_f1DbYlzY;
  ControlBinop cBinop_VnbqacwS;
  ControlBinop cBinop_vZBDpukt;
  ControlBinop cBinop_etEEQCzp;
  ControlIf cIf_zjFRVEfU;
  ControlSlice cSlice_nvoVxnqz;
  ControlVar cVar_K1Pp0HtM;
  ControlSlice cSlice_E9qgoYbl;
  ControlVar cVar_bMIl5PfJ;
  ControlSlice cSlice_KGd4b4xr;
  ControlVar cVar_HBBtyO8s;
  ControlSlice cSlice_NWbfFNKU;
  ControlVar cVar_x3LUnzeW;
  ControlBinop cBinop_rJEkH8xo;
  ControlBinop cBinop_niiCQMAw;
  ControlBinop cBinop_WsPQ7bYD;
  ControlBinop cBinop_UbKDGOMp;
  ControlBinop cBinop_WUC1RUoY;
  ControlBinop cBinop_Uqm0Cyrg;
  ControlBinop cBinop_0ykKmFna;
  ControlBinop cBinop_1dIvgceH;
  ControlVar cVar_ZJW8Yi5z;
  ControlBinop cBinop_mnXszDBr;
  ControlBinop cBinop_6Dh5MAKq;
  ControlBinop cBinop_6Tf7xrse;
  ControlBinop cBinop_FQ8p69K5;
  ControlBinop cBinop_Z07BMeXo;
  ControlBinop cBinop_KBLdL1xI;
  ControlBinop cBinop_ij7lfmdn;
  ControlBinop cBinop_7BGFeYBq;
  ControlVar cVar_F3TGriMZ;
  ControlVar cVar_enNXzGjb;
  ControlBinop cBinop_LLMJqa2G;
  ControlBinop cBinop_YjgcDy7q;
  ControlBinop cBinop_N5jnc89H;
  ControlBinop cBinop_7VDeuzKr;
  ControlBinop cBinop_56FyIYmw;
  ControlBinop cBinop_BLJ2Ru7z;
  ControlBinop cBinop_GbulahXl;
  ControlBinop cBinop_6sUokRvw;
  ControlBinop cBinop_F18irUFI;
  ControlBinop cBinop_fhMh6Y6V;
  ControlBinop cBinop_s3ge6ohp;
  ControlBinop cBinop_JtIKqRTC;
  ControlBinop cBinop_IOTd570B;
  ControlBinop cBinop_BcPDH0Qa;
  ControlBinop cBinop_1kQLf2NH;
  ControlBinop cBinop_IkhPHXpA;
  ControlBinop cBinop_aXUv7mOd;
  ControlBinop cBinop_jdf2ETPe;
  ControlBinop cBinop_G41EKEDu;
  ControlBinop cBinop_2o6xyIAP;
  ControlVar cVar_zec8Z3HH;
  ControlVar cVar_CrZRwEdo;
  ControlVar cVar_XmbCOdlB;
  ControlBinop cBinop_tcGdc2UQ;
  ControlBinop cBinop_VPmkB56d;
  ControlBinop cBinop_HgXN8QTh;
  ControlBinop cBinop_kxOQ41OI;
  ControlBinop cBinop_OKu7lXxe;
  ControlBinop cBinop_21hgzEDD;
  ControlBinop cBinop_1OhPZ55c;
  ControlBinop cBinop_iuXdoK12;
  ControlBinop cBinop_kstgPsYC;
  ControlBinop cBinop_zDlFAHxi;
  ControlBinop cBinop_sNnqV8QB;
  ControlBinop cBinop_HzdUFozX;
  ControlBinop cBinop_c7ElLOaA;
  ControlBinop cBinop_QFSSDvYY;
  ControlBinop cBinop_lMMvLqKc;
  ControlBinop cBinop_wzAj7jhj;
  ControlBinop cBinop_6BUc22ld;
  ControlBinop cBinop_qolZKtl7;
  ControlBinop cBinop_Kl9OfRsD;
  ControlBinop cBinop_DO9BKUj1;
  ControlBinop cBinop_JWLu63nu;
  ControlBinop cBinop_yhMWdz8l;
  ControlBinop cBinop_4hYxRLi3;
  ControlVar cVar_xbfRqYIB;
  ControlVar cVar_F0lcTAyr;
  ControlVar cVar_Wlp6iXWN;
  ControlBinop cBinop_WPHyYCDF;
  ControlBinop cBinop_989GPrnl;
  ControlBinop cBinop_57TlineR;
  ControlBinop cBinop_qu4S5WVO;
  ControlBinop cBinop_W5jrbI5F;
  ControlBinop cBinop_tel9uz70;
  ControlBinop cBinop_JklfyOO1;
  ControlBinop cBinop_MfeLWJbe;
  ControlBinop cBinop_js7wLJby;
  ControlBinop cBinop_wIiluudP;
  ControlBinop cBinop_glGHbvMc;
  ControlBinop cBinop_z4oCwVhg;
  SignalVarf sVarf_d5kWGl8E;
  SignalVarf sVarf_nY8oV2iA;
  SignalVarf sVarf_tlMz0CMM;
  ControlSlice cSlice_xOYwOo8d;
  ControlVar cVar_KidvNyaD;
  ControlVar cVar_gFZafOdl;
  ControlIf cIf_W4PTZWYJ;
  ControlIf cIf_7fk3U9T6;
  ControlBinop cBinop_7ctSDmxU;
  ControlBinop cBinop_JuLDjXzs;
  ControlBinop cBinop_pXT6eOi5;
  ControlBinop cBinop_hhtACbFR;
  ControlBinop cBinop_Bq3ughep;
  ControlIf cIf_Rt7TjMTn;
  ControlBinop cBinop_rxHDCNB1;
  ControlBinop cBinop_YkHx87AN;
  ControlBinop cBinop_ddhTF2nL;
  ControlBinop cBinop_WYbNvdgf;
  ControlBinop cBinop_Py3blVey;
  ControlVar cVar_SKMtx35j;
  ControlIf cIf_q0en241i;
  ControlIf cIf_MLibaInc;
  ControlBinop cBinop_UOVGdAPN;
  ControlBinop cBinop_vgnSckwy;
  ControlBinop cBinop_yX4uMiYc;
  ControlBinop cBinop_YMbltdkp;
  ControlBinop cBinop_0F9BbzjS;
  ControlIf cIf_3f6Pb8fB;
  ControlBinop cBinop_8xdoIce8;
  ControlBinop cBinop_s2NbjQXs;
  ControlBinop cBinop_Boj75aoH;
  ControlBinop cBinop_eF29l7OF;
  ControlBinop cBinop_CqX6ZbIG;
  ControlVar cVar_1MklJSB2;
  ControlIf cIf_0fOC3rn1;
  ControlIf cIf_N5xyGVUl;
  ControlBinop cBinop_ycpGkJJM;
  ControlBinop cBinop_O1GuoVF4;
  ControlBinop cBinop_mD9Vep9Q;
  ControlBinop cBinop_3WhPqvkp;
  ControlBinop cBinop_jrqoj0Xf;
  ControlIf cIf_XyW3LIt5;
  ControlBinop cBinop_PjVmlBnD;
  ControlBinop cBinop_yjuo7DLt;
  ControlBinop cBinop_gqfIyji9;
  ControlBinop cBinop_Vxc37eMM;
  ControlBinop cBinop_v7gazb9g;
  ControlIf cIf_XqaMtaaH;
  ControlSlice cSlice_aEJYfduj;
  ControlVar cVar_fn6yizAB;
  ControlSlice cSlice_pMoz4XKd;
  ControlVar cVar_wBWLGulE;
  ControlSlice cSlice_xbpLVNjP;
  ControlVar cVar_aak4CMLg;
  ControlSlice cSlice_qKRwxHPa;
  ControlVar cVar_4WK0mqLM;
  ControlBinop cBinop_sgUxyd4a;
  ControlBinop cBinop_Kb6XA1Wt;
  ControlBinop cBinop_p2tYIZ1R;
  ControlBinop cBinop_8iM2kOm6;
  ControlBinop cBinop_V1fltldE;
  ControlBinop cBinop_lo27Kg3b;
  ControlBinop cBinop_9eWDhaLu;
  ControlBinop cBinop_EfOZpjwr;
  ControlVar cVar_4bHbXLaQ;
  ControlBinop cBinop_jHbW07hv;
  ControlBinop cBinop_SWYmjATR;
  ControlBinop cBinop_6gMrCr4w;
  ControlBinop cBinop_TolrXJzL;
  ControlBinop cBinop_R70Zapxt;
  ControlBinop cBinop_BO4IGdXG;
  ControlBinop cBinop_VyufPNEE;
  ControlBinop cBinop_YqzCSnBi;
  ControlVar cVar_Zh3y56Fd;
  ControlVar cVar_tkggtXxX;
  ControlBinop cBinop_meCjBfHS;
  ControlBinop cBinop_QO2u9eel;
  ControlBinop cBinop_ieS5lLFC;
  ControlBinop cBinop_XcD3cal7;
  ControlBinop cBinop_V1y7oiOL;
  ControlBinop cBinop_VUtT2w2i;
  ControlBinop cBinop_yZBXIPVt;
  ControlBinop cBinop_Bpmz1gwD;
  ControlBinop cBinop_H8fXwPqG;
  ControlBinop cBinop_SApvVf7s;
  ControlBinop cBinop_OPWAlESW;
  ControlBinop cBinop_mITVhGNK;
  ControlBinop cBinop_Fh2MiVvX;
  ControlBinop cBinop_yRSpgA8J;
  ControlBinop cBinop_8s17cltr;
  ControlBinop cBinop_kIKoZz3P;
  ControlBinop cBinop_tfgT9QUO;
  ControlBinop cBinop_hLaM5Prh;
  ControlBinop cBinop_YZHd8BwN;
  ControlBinop cBinop_pZVINLc5;
  ControlVar cVar_gCvuXMqq;
  ControlVar cVar_UFWi8QIC;
  ControlVar cVar_8JvfzCZ4;
  ControlBinop cBinop_ujfdt8wO;
  ControlBinop cBinop_7NfDegZ6;
  ControlBinop cBinop_SjzUgJGo;
  ControlBinop cBinop_WJiu4BV5;
  ControlBinop cBinop_bBeTpKOT;
  ControlBinop cBinop_5wz3Ptf5;
  ControlBinop cBinop_iNroQELg;
  ControlBinop cBinop_tRrkvROi;
  ControlBinop cBinop_oe5WCQBA;
  ControlBinop cBinop_Z11vtAK5;
  ControlBinop cBinop_kcTqbeuc;
  ControlBinop cBinop_gxXIw6Ft;
  ControlBinop cBinop_eWvEeciI;
  ControlBinop cBinop_xBQ54wf7;
  ControlBinop cBinop_kXMEpoNv;
  ControlBinop cBinop_zeI0YxN4;
  ControlBinop cBinop_N5Ry2SR3;
  ControlBinop cBinop_7RckqJB2;
  ControlBinop cBinop_5bbrmsS1;
  ControlBinop cBinop_NpMcn6b3;
  ControlBinop cBinop_xJvvB3Oo;
  ControlBinop cBinop_G1fAxiTd;
  ControlBinop cBinop_Q1hqQk25;
  ControlVar cVar_xiwsHefm;
  ControlVar cVar_vzw5CR0U;
  ControlVar cVar_awQgZzb1;
  ControlBinop cBinop_2OlfAyLm;
  ControlBinop cBinop_JvRDfOQ2;
  ControlBinop cBinop_geL4CgxF;
  ControlBinop cBinop_avBOLBh0;
  ControlBinop cBinop_vdOSbLl3;
  ControlBinop cBinop_2m6ciMGj;
  ControlBinop cBinop_YLCs2jlz;
  ControlBinop cBinop_wcO2ai0P;
  ControlBinop cBinop_cyL6EpDN;
  ControlBinop cBinop_HXZusjfJ;
  ControlBinop cBinop_AvLrJvYP;
  ControlBinop cBinop_NRv8x9Cs;
  SignalVarf sVarf_wY564qPg;
  SignalVarf sVarf_5C0Ym30c;
  SignalVarf sVarf_G6O1Nrgj;
  SignalVarf sVarf_YvhMMD4q;
  SignalVarf sVarf_mW5jFCoy;
  SignalVarf sVarf_4v767zBG;
  SignalVarf sVarf_sxOnOyUB;
  SignalVarf sVarf_Cz6azwi8;
  SignalVarf sVarf_a88uIjhL;
  ControlVar cVar_WXZBWiDm;
  ControlVar cVar_CynyOav2;
  ControlBinop cBinop_zi8QLL5u;
  ControlBinop cBinop_gQ5uc0So;
  ControlBinop cBinop_hcyvxBdi;
  ControlBinop cBinop_NSK7JRC8;
  ControlBinop cBinop_ab1MBNp2;
  ControlBinop cBinop_Z9ikRXFn;
  ControlBinop cBinop_ivJUJaQ6;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
