/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_26RVCf28);
  numBytes += sLine_init(&sLine_KyVLa1UB);
  numBytes += sLine_init(&sLine_7nRYMCXn);
  numBytes += sLine_init(&sLine_YGe39g7z);
  numBytes += sLine_init(&sLine_9pQcRCGk);
  numBytes += sBiquad_init(&sBiquad_s_EplGjzsd);
  numBytes += sLine_init(&sLine_Fp9h5P4u);
  numBytes += sLine_init(&sLine_vOIdAb0w);
  numBytes += sLine_init(&sLine_uQUaTdyF);
  numBytes += sLine_init(&sLine_CJZa2lb7);
  numBytes += sBiquad_init(&sBiquad_s_xi38GoFM);
  numBytes += sLine_init(&sLine_u1zEhbnB);
  numBytes += sLine_init(&sLine_ypbWiiaM);
  numBytes += sLine_init(&sLine_bWKx1Kb5);
  numBytes += sLine_init(&sLine_EoWDm78S);
  numBytes += sLine_init(&sLine_5q0WqqtD);
  numBytes += sBiquad_init(&sBiquad_s_EIDJ9JG5);
  numBytes += sLine_init(&sLine_3avMmArf);
  numBytes += sLine_init(&sLine_LpFBQGgW);
  numBytes += sLine_init(&sLine_mJiwoo2r);
  numBytes += sLine_init(&sLine_eNrooVM3);
  numBytes += sLine_init(&sLine_hOZtJvAw);
  numBytes += sBiquad_init(&sBiquad_s_sxZPvPz9);
  numBytes += sLine_init(&sLine_5uzwBRqX);
  numBytes += sLine_init(&sLine_O02kYo6Y);
  numBytes += sLine_init(&sLine_BbZoOUuV);
  numBytes += sLine_init(&sLine_BszWr8sb);
  numBytes += sBiquad_init(&sBiquad_s_1lqnmFQd);
  numBytes += sLine_init(&sLine_n3i9fv4Z);
  numBytes += sLine_init(&sLine_lHdEctmj);
  numBytes += sLine_init(&sLine_uBmcKOCS);
  numBytes += sLine_init(&sLine_00CE6qrS);
  numBytes += sLine_init(&sLine_I9inOEZZ);
  numBytes += sBiquad_init(&sBiquad_s_fVVEeYHk);
  numBytes += cVar_init_f(&cVar_dsN8pkgu, 0.0f);
  numBytes += cVar_init_f(&cVar_JADpV1aH, 0.0f);
  numBytes += cVar_init_f(&cVar_kvGWOCty, 0.0f);
  numBytes += cVar_init_f(&cVar_1aBWMhMN, 0.0f);
  numBytes += cSlice_init(&cSlice_g9SHf82X, 1, -1);
  numBytes += cVar_init_f(&cVar_wf06aHRM, 1337.0f);
  numBytes += cVar_init_f(&cVar_gf4T7K3Q, 0.0f);
  numBytes += cIf_init(&cIf_Co8et8An, false);
  numBytes += cIf_init(&cIf_5PQR4DpW, false);
  numBytes += cBinop_init(&cBinop_a45QNF6u, 0.0f); // __pow
  numBytes += cIf_init(&cIf_j4mxw0yr, false);
  numBytes += cBinop_init(&cBinop_e9J7bY1U, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_emmsuAKO, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_3tZPJrph, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_71BrfrCC, 0.0f);
  numBytes += cIf_init(&cIf_W6CXKOiK, false);
  numBytes += cIf_init(&cIf_ac6NULHu, false);
  numBytes += cBinop_init(&cBinop_Kr7Ap6Ng, 0.0f); // __pow
  numBytes += cIf_init(&cIf_S0a6yJht, false);
  numBytes += cBinop_init(&cBinop_yW57TctG, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Z2kBgesx, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_331w1JAv, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_8L6MRkm5, 0.0f);
  numBytes += cIf_init(&cIf_Yj5eN3LR, false);
  numBytes += cIf_init(&cIf_5HMUKueZ, false);
  numBytes += cBinop_init(&cBinop_wrWNWI7T, 0.0f); // __pow
  numBytes += cIf_init(&cIf_pWj8c71W, false);
  numBytes += cBinop_init(&cBinop_VnbqacwS, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_vZBDpukt, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_etEEQCzp, -15.0f); // __eq
  numBytes += cIf_init(&cIf_zjFRVEfU, false);
  numBytes += cSlice_init(&cSlice_nvoVxnqz, 1, -1);
  numBytes += cVar_init_f(&cVar_K1Pp0HtM, 0.0f);
  numBytes += cSlice_init(&cSlice_E9qgoYbl, 1, -1);
  numBytes += cVar_init_f(&cVar_bMIl5PfJ, 0.0f);
  numBytes += cSlice_init(&cSlice_KGd4b4xr, 1, -1);
  numBytes += cVar_init_f(&cVar_HBBtyO8s, 0.0f);
  numBytes += cSlice_init(&cSlice_NWbfFNKU, 1, -1);
  numBytes += cVar_init_f(&cVar_x3LUnzeW, 0.313f);
  numBytes += cBinop_init(&cBinop_niiCQMAw, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_WsPQ7bYD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_ZJW8Yi5z, 0.0f);
  numBytes += cVar_init_f(&cVar_F3TGriMZ, 1337.0f);
  numBytes += cVar_init_f(&cVar_enNXzGjb, 0.3f);
  numBytes += cBinop_init(&cBinop_YjgcDy7q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_56FyIYmw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BLJ2Ru7z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GbulahXl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6sUokRvw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_F18irUFI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_s3ge6ohp, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_JtIKqRTC, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_zec8Z3HH, 0.0f);
  numBytes += cVar_init_f(&cVar_CrZRwEdo, 1337.0f);
  numBytes += cVar_init_f(&cVar_XmbCOdlB, 0.313f);
  numBytes += cBinop_init(&cBinop_VPmkB56d, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OKu7lXxe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_21hgzEDD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1OhPZ55c, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iuXdoK12, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zDlFAHxi, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_sNnqV8QB, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_xbfRqYIB, 0.0f);
  numBytes += cVar_init_f(&cVar_F0lcTAyr, 1037.0f);
  numBytes += cVar_init_f(&cVar_Wlp6iXWN, 0.4f);
  numBytes += cBinop_init(&cBinop_989GPrnl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_W5jrbI5F, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tel9uz70, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JklfyOO1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MfeLWJbe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_js7wLJby, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_d5kWGl8E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nY8oV2iA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tlMz0CMM, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_xOYwOo8d, 1, -1);
  numBytes += cVar_init_f(&cVar_KidvNyaD, 1337.0f);
  numBytes += cVar_init_f(&cVar_gFZafOdl, 0.0f);
  numBytes += cIf_init(&cIf_W4PTZWYJ, false);
  numBytes += cIf_init(&cIf_7fk3U9T6, false);
  numBytes += cBinop_init(&cBinop_7ctSDmxU, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Rt7TjMTn, false);
  numBytes += cBinop_init(&cBinop_ddhTF2nL, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_WYbNvdgf, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Py3blVey, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_SKMtx35j, 0.0f);
  numBytes += cIf_init(&cIf_q0en241i, false);
  numBytes += cIf_init(&cIf_MLibaInc, false);
  numBytes += cBinop_init(&cBinop_UOVGdAPN, 0.0f); // __pow
  numBytes += cIf_init(&cIf_3f6Pb8fB, false);
  numBytes += cBinop_init(&cBinop_Boj75aoH, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_eF29l7OF, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_CqX6ZbIG, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_1MklJSB2, 0.0f);
  numBytes += cIf_init(&cIf_0fOC3rn1, false);
  numBytes += cIf_init(&cIf_N5xyGVUl, false);
  numBytes += cBinop_init(&cBinop_ycpGkJJM, 0.0f); // __pow
  numBytes += cIf_init(&cIf_XyW3LIt5, false);
  numBytes += cBinop_init(&cBinop_gqfIyji9, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Vxc37eMM, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_v7gazb9g, -15.0f); // __eq
  numBytes += cIf_init(&cIf_XqaMtaaH, false);
  numBytes += cSlice_init(&cSlice_aEJYfduj, 1, -1);
  numBytes += cVar_init_f(&cVar_fn6yizAB, 0.0f);
  numBytes += cSlice_init(&cSlice_pMoz4XKd, 1, -1);
  numBytes += cVar_init_f(&cVar_wBWLGulE, 0.0f);
  numBytes += cSlice_init(&cSlice_xbpLVNjP, 1, -1);
  numBytes += cVar_init_f(&cVar_aak4CMLg, 0.0f);
  numBytes += cSlice_init(&cSlice_qKRwxHPa, 1, -1);
  numBytes += cVar_init_f(&cVar_4WK0mqLM, 0.313f);
  numBytes += cBinop_init(&cBinop_Kb6XA1Wt, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_p2tYIZ1R, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_4bHbXLaQ, 0.0f);
  numBytes += cVar_init_f(&cVar_Zh3y56Fd, 1337.0f);
  numBytes += cVar_init_f(&cVar_tkggtXxX, 0.3f);
  numBytes += cBinop_init(&cBinop_QO2u9eel, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_V1y7oiOL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VUtT2w2i, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yZBXIPVt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Bpmz1gwD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_H8fXwPqG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OPWAlESW, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_mITVhGNK, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_gCvuXMqq, 0.0f);
  numBytes += cVar_init_f(&cVar_UFWi8QIC, 1337.0f);
  numBytes += cVar_init_f(&cVar_8JvfzCZ4, 0.313f);
  numBytes += cBinop_init(&cBinop_7NfDegZ6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bBeTpKOT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5wz3Ptf5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_iNroQELg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tRrkvROi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Z11vtAK5, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_kcTqbeuc, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_xiwsHefm, 0.0f);
  numBytes += cVar_init_f(&cVar_vzw5CR0U, 1037.0f);
  numBytes += cVar_init_f(&cVar_awQgZzb1, 0.4f);
  numBytes += cBinop_init(&cBinop_JvRDfOQ2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vdOSbLl3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2m6ciMGj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YLCs2jlz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wcO2ai0P, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cyL6EpDN, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_wY564qPg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5C0Ym30c, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_G6O1Nrgj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YvhMMD4q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mW5jFCoy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4v767zBG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sxOnOyUB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Cz6azwi8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_a88uIjhL, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_WXZBWiDm, 5705.6f);
  numBytes += cVar_init_f(&cVar_CynyOav2, 313.3f);
  numBytes += cBinop_init(&cBinop_zi8QLL5u, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_gQ5uc0So, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_hcyvxBdi, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CxZB78YB_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_E98oWkT5_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FL9dNFWY_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_I4t9GnMK_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JuQYGT0G_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6EXhVNgR_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hK32FfeX_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_61aDsS7l_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CTK1nFOm_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KZTT3m08_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Nmbe8yW0_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NeF5E0XD_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mdVnO129_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7vxng0Me_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ekk0F6qf_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ttvWNK5K_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9jTFKy0i_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_j8asidhY_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XkfBpn8X_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ss85hQBr_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yNG4WYD5_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PWdMmHzd_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e64Qx61G_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xpos8E3d_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lutEfvGS_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LL8CZACV_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qiwl3uw7_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_61QTNAwo_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ah7KPUEQ_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_INBWazm2_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dismy5a8_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6dljYM9J_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Hj8M30AB_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_dsN8pkgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ecvRDOvq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_JADpV1aH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wSsM5OnB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_kvGWOCty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JYxt0HWn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_1aBWMhMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sztrVgAF_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IpR81aCP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fAS4vuX8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CDOUGRqt_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_uw5dsosA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_g9SHf82X, 0, m, &cSlice_g9SHf82X_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ut8h9SwG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_g9SHf82X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yAofSMS7_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yAofSMS7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_wf06aHRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yAofSMS7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_yAofSMS7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hK32FfeX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_gf4T7K3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rNzNdQ8N_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Co8et8An, 0, m, &cIf_Co8et8An_sendMessage);
}

void Heavy_WSTD_EQ::cIf_Co8et8An_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xYeGN1K3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_5PQR4DpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_H7e0UDOf_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_lGWr1c2I_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_f2VD6ZHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_a45QNF6u, HV_BINOP_POW, 0, m, &cBinop_a45QNF6u_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_a45QNF6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j4mxw0yr, 0, m, &cIf_j4mxw0yr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MmgdZZyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_sqMZ2guP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qM7uK6dh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ttS6ImW3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QY2LWqjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5PQR4DpW, 0, m, &cIf_5PQR4DpW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ttS6ImW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5PQR4DpW, 1, m, &cIf_5PQR4DpW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lGWr1c2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_MmgdZZyH_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_H7e0UDOf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_j4mxw0yr, 0, m, &cIf_j4mxw0yr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sqMZ2guP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_a45QNF6u, HV_BINOP_POW, 1, m, &cBinop_a45QNF6u_sendMessage);
  cMsg_f2VD6ZHu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_j4mxw0yr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_d5kWGl8E, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_rNzNdQ8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Co8et8An, 1, m, &cIf_Co8et8An_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xYeGN1K3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_emmsuAKO, HV_BINOP_GREATER_THAN, 1, m, &cBinop_emmsuAKO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3tZPJrph, HV_BINOP_EQ, 1, m, &cBinop_3tZPJrph_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_apID8Na3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_e9J7bY1U, HV_BINOP_ADD, 0, m, &cBinop_e9J7bY1U_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_e9J7bY1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qM7uK6dh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QY2LWqjS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_emmsuAKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_j4mxw0yr, 1, m, &cIf_j4mxw0yr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3tZPJrph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nVclHjLz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_nVclHjLz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_d5kWGl8E, m);
}

void Heavy_WSTD_EQ::cCast_1WO6phaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gf4T7K3Q, 0, m, &cVar_gf4T7K3Q_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NoPA3ptx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_apID8Na3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_d0powlEg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e9J7bY1U, HV_BINOP_ADD, 1, m, &cBinop_e9J7bY1U_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_emmsuAKO, HV_BINOP_GREATER_THAN, 0, m, &cBinop_emmsuAKO_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3tZPJrph, HV_BINOP_EQ, 0, m, &cBinop_3tZPJrph_sendMessage);
}

void Heavy_WSTD_EQ::cVar_71BrfrCC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Wb5y8Vaq_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_W6CXKOiK, 0, m, &cIf_W6CXKOiK_sendMessage);
}

void Heavy_WSTD_EQ::cIf_W6CXKOiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_qnQMdcqN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_ac6NULHu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_iX8uto0D_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_TyUENvTE_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_IGsBLe5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kr7Ap6Ng, HV_BINOP_POW, 0, m, &cBinop_Kr7Ap6Ng_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Kr7Ap6Ng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S0a6yJht, 0, m, &cIf_S0a6yJht_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ov3JTbxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_W87zfquI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_nrsdHJiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YfFyFz2C_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qkgF3dHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ac6NULHu, 0, m, &cIf_ac6NULHu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YfFyFz2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ac6NULHu, 1, m, &cIf_ac6NULHu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TyUENvTE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Ov3JTbxl_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_iX8uto0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_S0a6yJht, 0, m, &cIf_S0a6yJht_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_W87zfquI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kr7Ap6Ng, HV_BINOP_POW, 1, m, &cBinop_Kr7Ap6Ng_sendMessage);
  cMsg_IGsBLe5f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_S0a6yJht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wIiluudP_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_glGHbvMc_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_z4oCwVhg_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_Wb5y8Vaq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_W6CXKOiK, 1, m, &cIf_W6CXKOiK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qnQMdcqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z2kBgesx, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Z2kBgesx_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_331w1JAv, HV_BINOP_EQ, 1, m, &cBinop_331w1JAv_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_uiNK9jks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yW57TctG, HV_BINOP_ADD, 0, m, &cBinop_yW57TctG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yW57TctG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nrsdHJiT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qkgF3dHh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Z2kBgesx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_S0a6yJht, 1, m, &cIf_S0a6yJht_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_331w1JAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r1Xui1BJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_r1Xui1BJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_wIiluudP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_glGHbvMc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_z4oCwVhg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oSy4fS3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uiNK9jks_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_3DPqSU0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yW57TctG, HV_BINOP_ADD, 1, m, &cBinop_yW57TctG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z2kBgesx, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Z2kBgesx_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_331w1JAv, HV_BINOP_EQ, 0, m, &cBinop_331w1JAv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iaqoXGhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_71BrfrCC, 0, m, &cVar_71BrfrCC_sendMessage);
}

void Heavy_WSTD_EQ::cVar_8L6MRkm5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rFezQiMy_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Yj5eN3LR, 0, m, &cIf_Yj5eN3LR_sendMessage);
}

void Heavy_WSTD_EQ::cIf_Yj5eN3LR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_f1DbYlzY_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_5HMUKueZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_bSOIsNPo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_q1m85ME4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_hDY4GOAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wrWNWI7T, HV_BINOP_POW, 0, m, &cBinop_wrWNWI7T_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wrWNWI7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pWj8c71W, 0, m, &cIf_pWj8c71W_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yQxHJvHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_W7kJA1l9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_t5S5bJb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Vfz3sBUA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AJ5RlONn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5HMUKueZ, 0, m, &cIf_5HMUKueZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Vfz3sBUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5HMUKueZ, 1, m, &cIf_5HMUKueZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_q1m85ME4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_yQxHJvHr_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_bSOIsNPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_pWj8c71W, 0, m, &cIf_pWj8c71W_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_W7kJA1l9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wrWNWI7T, HV_BINOP_POW, 1, m, &cBinop_wrWNWI7T_sendMessage);
  cMsg_hDY4GOAS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_pWj8c71W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_tlMz0CMM, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_rFezQiMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yj5eN3LR, 1, m, &cIf_Yj5eN3LR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_f1DbYlzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vZBDpukt, HV_BINOP_GREATER_THAN, 1, m, &cBinop_vZBDpukt_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_etEEQCzp, HV_BINOP_EQ, 1, m, &cBinop_etEEQCzp_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_WZbGiNcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VnbqacwS, HV_BINOP_ADD, 0, m, &cBinop_VnbqacwS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VnbqacwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t5S5bJb4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AJ5RlONn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vZBDpukt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pWj8c71W, 1, m, &cIf_pWj8c71W_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_etEEQCzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sbmwefdI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_sbmwefdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_tlMz0CMM, m);
}

void Heavy_WSTD_EQ::cCast_WLKBPtO8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VnbqacwS, HV_BINOP_ADD, 1, m, &cBinop_VnbqacwS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vZBDpukt, HV_BINOP_GREATER_THAN, 0, m, &cBinop_vZBDpukt_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_etEEQCzp, HV_BINOP_EQ, 0, m, &cBinop_etEEQCzp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_UzvBgY0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WZbGiNcF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_jDpKHe6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8L6MRkm5, 0, m, &cVar_8L6MRkm5_sendMessage);
}

void Heavy_WSTD_EQ::cIf_zjFRVEfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_nY8oV2iA, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_4rctmv0a_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nvoVxnqz, 0, m, &cSlice_nvoVxnqz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_qPNfG8lF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_nvoVxnqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hNrWwet9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hNrWwet9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_K1Pp0HtM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hNrWwet9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_hNrWwet9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JuQYGT0G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_qPNfG8lF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_E9qgoYbl, 0, m, &cSlice_E9qgoYbl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_uw5dsosA_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_E9qgoYbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NO3Yao07_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NO3Yao07_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_bMIl5PfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NO3Yao07_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_NO3Yao07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CTK1nFOm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_ut8h9SwG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_KGd4b4xr, 0, m, &cSlice_KGd4b4xr_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nWflMqg2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_KGd4b4xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Fv34fGcF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Fv34fGcF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_HBBtyO8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Fv34fGcF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Fv34fGcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6EXhVNgR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_nWflMqg2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NWbfFNKU, 0, m, &cSlice_NWbfFNKU_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_NWbfFNKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DK4Ke1Sb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DK4Ke1Sb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_x3LUnzeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DK4Ke1Sb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_DK4Ke1Sb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_61aDsS7l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Ib5dNJgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_26RVCf28, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_TPz8fMB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KyVLa1UB, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_sqOcqUgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7nRYMCXn, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_AZfEWJfR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YGe39g7z, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_FKmgDO4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9pQcRCGk, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_UngnOGwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Te1C8iMa_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_Te1C8iMa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_niiCQMAw, HV_BINOP_DIVIDE, 1, m, &cBinop_niiCQMAw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yjS1eOsM_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_nnQNrWlU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_rJEkH8xo_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_RKxsEXp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_nnQNrWlU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_rJEkH8xo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_niiCQMAw, HV_BINOP_DIVIDE, 0, m, &cBinop_niiCQMAw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yjS1eOsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RKxsEXp5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_niiCQMAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WsPQ7bYD, HV_BINOP_MULTIPLY, 1, m, &cBinop_WsPQ7bYD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WsPQ7bYD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CoDeZ2rp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0eZO9AR4_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_RC6glNRa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3Hx28NQx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_p7ehRLb6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HdNGBgVb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_UbKDGOMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_WUC1RUoY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WUC1RUoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WsPQ7bYD, HV_BINOP_MULTIPLY, 0, m, &cBinop_WsPQ7bYD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Uqm0Cyrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_0ykKmFna_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0ykKmFna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N8X8yzaO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1dIvgceH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZJW8Yi5z, 1, m, &cVar_ZJW8Yi5z_sendMessage);
}

void Heavy_WSTD_EQ::cVar_ZJW8Yi5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PARXzEyA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_mnXszDBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_56FyIYmw, HV_BINOP_MULTIPLY, 1, m, &cBinop_56FyIYmw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6Dh5MAKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mnXszDBr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6Tf7xrse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FQ8p69K5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FQ8p69K5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BLJ2Ru7z, HV_BINOP_MULTIPLY, 1, m, &cBinop_BLJ2Ru7z_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Z07BMeXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GbulahXl, HV_BINOP_MULTIPLY, 1, m, &cBinop_GbulahXl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KBLdL1xI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Z07BMeXo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ij7lfmdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6sUokRvw, HV_BINOP_MULTIPLY, 1, m, &cBinop_6sUokRvw_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_MdLD9Ptp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7BGFeYBq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7BGFeYBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F18irUFI, HV_BINOP_MULTIPLY, 1, m, &cBinop_F18irUFI_sendMessage);
}

void Heavy_WSTD_EQ::cVar_F3TGriMZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zKMhMd4L_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_UbKDGOMp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O2xORRTk_sendMessage);
}

void Heavy_WSTD_EQ::cVar_enNXzGjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Uqm0Cyrg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0eZO9AR4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_p7ehRLb6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CoDeZ2rp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_RC6glNRa_sendMessage);
}

void Heavy_WSTD_EQ::cSend_3Hx28NQx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NeF5E0XD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_HdNGBgVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Nmbe8yW0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_33rwzdS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KZTT3m08_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_N8X8yzaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_LLMJqa2G_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LLMJqa2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YjgcDy7q, HV_BINOP_MULTIPLY, 1, m, &cBinop_YjgcDy7q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YjgcDy7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_N5jnc89H_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_N5jnc89H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_33rwzdS2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_PARXzEyA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7VDeuzKr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7VDeuzKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5TsdAeJS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FbEEMQRV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PNqmJ4Fz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JVIhAMxE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0ODhCxy7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YdsZlQ8j_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_56FyIYmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ib5dNJgM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_BLJ2Ru7z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TPz8fMB7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_GbulahXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sqOcqUgV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_6sUokRvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AZfEWJfR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_F18irUFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FKmgDO4l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_RFZDwSfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_F3TGriMZ, 0, m, &cVar_F3TGriMZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_P25apAAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_enNXzGjb, 1, m, &cVar_enNXzGjb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FbEEMQRV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F18irUFI, HV_BINOP_MULTIPLY, 0, m, &cBinop_F18irUFI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0ODhCxy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BLJ2Ru7z, HV_BINOP_MULTIPLY, 0, m, &cBinop_BLJ2Ru7z_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JVIhAMxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GbulahXl, HV_BINOP_MULTIPLY, 0, m, &cBinop_GbulahXl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5TsdAeJS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_PNqmJ4Fz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6sUokRvw, HV_BINOP_MULTIPLY, 0, m, &cBinop_6sUokRvw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YdsZlQ8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_56FyIYmw, HV_BINOP_MULTIPLY, 0, m, &cBinop_56FyIYmw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_O2xORRTk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZJW8Yi5z, 0, m, &cVar_ZJW8Yi5z_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zKMhMd4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_enNXzGjb, 0, m, &cVar_enNXzGjb_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_n9ZTaP6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Fp9h5P4u, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_XozhnokY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vOIdAb0w, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_KEqaOK15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uQUaTdyF, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_9Oyr6eKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CJZa2lb7, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_cn3zdHj9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_r7gN6QDo_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_r7gN6QDo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s3ge6ohp, HV_BINOP_DIVIDE, 1, m, &cBinop_s3ge6ohp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h6hTDmfL_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_lypwa6Y7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_fhMh6Y6V_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_FeSosP2N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_lypwa6Y7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fhMh6Y6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_s3ge6ohp, HV_BINOP_DIVIDE, 0, m, &cBinop_s3ge6ohp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_h6hTDmfL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FeSosP2N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_s3ge6ohp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JtIKqRTC, HV_BINOP_MULTIPLY, 1, m, &cBinop_JtIKqRTC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JtIKqRTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mm3kHydS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GW3wWIDC_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_2eBvqV8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QVQRTrD3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_OPmFSFXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WZwZ5Uzy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_IOTd570B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_BcPDH0Qa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BcPDH0Qa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JtIKqRTC, HV_BINOP_MULTIPLY, 0, m, &cBinop_JtIKqRTC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1kQLf2NH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_IkhPHXpA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IkhPHXpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hzB6KAn0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_aXUv7mOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_21hgzEDD, HV_BINOP_MULTIPLY, 1, m, &cBinop_21hgzEDD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jdf2ETPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zec8Z3HH, 1, m, &cVar_zec8Z3HH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_G41EKEDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1OhPZ55c, HV_BINOP_MULTIPLY, 1, m, &cBinop_1OhPZ55c_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_GZeLxtxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2o6xyIAP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2o6xyIAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iuXdoK12, HV_BINOP_MULTIPLY, 1, m, &cBinop_iuXdoK12_sendMessage);
}

void Heavy_WSTD_EQ::cVar_zec8Z3HH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HfNFMBTv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_CrZRwEdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2fIqKcAT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_IOTd570B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kUIWcMxl_sendMessage);
}

void Heavy_WSTD_EQ::cVar_XmbCOdlB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_1kQLf2NH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GW3wWIDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_OPmFSFXx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Mm3kHydS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_2eBvqV8q_sendMessage);
}

void Heavy_WSTD_EQ::cSend_QVQRTrD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ekk0F6qf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_WZwZ5Uzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7vxng0Me_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_j3sOga0r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mdVnO129_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_hzB6KAn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tcGdc2UQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tcGdc2UQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VPmkB56d, HV_BINOP_MULTIPLY, 1, m, &cBinop_VPmkB56d_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VPmkB56d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_HgXN8QTh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HgXN8QTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_j3sOga0r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_HfNFMBTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kxOQ41OI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kxOQ41OI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0CxSuwkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jEqyrcM4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_68SmcS08_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RXwBV7di_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OKu7lXxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n9ZTaP6E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_21hgzEDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XozhnokY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1OhPZ55c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KEqaOK15_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_iuXdoK12_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9Oyr6eKj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_KuiEuRjc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CrZRwEdo, 0, m, &cVar_CrZRwEdo_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Mw5sswZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XmbCOdlB, 1, m, &cVar_XmbCOdlB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2fIqKcAT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XmbCOdlB, 0, m, &cVar_XmbCOdlB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_kUIWcMxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zec8Z3HH, 0, m, &cVar_zec8Z3HH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jEqyrcM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1OhPZ55c, HV_BINOP_MULTIPLY, 0, m, &cBinop_1OhPZ55c_sendMessage);
}

void Heavy_WSTD_EQ::cCast_68SmcS08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_21hgzEDD, HV_BINOP_MULTIPLY, 0, m, &cBinop_21hgzEDD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RXwBV7di_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OKu7lXxe, HV_BINOP_MULTIPLY, 0, m, &cBinop_OKu7lXxe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0CxSuwkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iuXdoK12, HV_BINOP_MULTIPLY, 0, m, &cBinop_iuXdoK12_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Fkfi1nQ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_u1zEhbnB, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_BtF9vtSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ypbWiiaM, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_CJd2suN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bWKx1Kb5, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Ruc1xKEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EoWDm78S, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_UcZD0oZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5q0WqqtD, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_r7SZ1GKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ls5uWwR1_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_ls5uWwR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zDlFAHxi, HV_BINOP_DIVIDE, 1, m, &cBinop_zDlFAHxi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B9UkE6l3_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_t1hijasF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_kstgPsYC_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_cqH97wRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_t1hijasF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kstgPsYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zDlFAHxi, HV_BINOP_DIVIDE, 0, m, &cBinop_zDlFAHxi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_B9UkE6l3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cqH97wRI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_zDlFAHxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sNnqV8QB, HV_BINOP_MULTIPLY, 1, m, &cBinop_sNnqV8QB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sNnqV8QB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eblvbmvP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N0J0SCzx_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_07OTzmJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lVrwpXOd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_pTWhHgJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gLmsyqG5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_HzdUFozX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_c7ElLOaA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_c7ElLOaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sNnqV8QB, HV_BINOP_MULTIPLY, 0, m, &cBinop_sNnqV8QB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QFSSDvYY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_lMMvLqKc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lMMvLqKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4McVhf0f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_wzAj7jhj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W5jrbI5F, HV_BINOP_MULTIPLY, 1, m, &cBinop_W5jrbI5F_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_CXsN8PNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_6BUc22ld_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6BUc22ld_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_wzAj7jhj_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_lWvAI4JD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_qolZKtl7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qolZKtl7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tel9uz70, HV_BINOP_MULTIPLY, 1, m, &cBinop_tel9uz70_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Kl9OfRsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JklfyOO1, HV_BINOP_MULTIPLY, 1, m, &cBinop_JklfyOO1_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_16PfvYlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_DO9BKUj1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DO9BKUj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Kl9OfRsD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JWLu63nu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xbfRqYIB, 1, m, &cVar_xbfRqYIB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yhMWdz8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MfeLWJbe, HV_BINOP_MULTIPLY, 1, m, &cBinop_MfeLWJbe_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_DRsrN7z7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_4hYxRLi3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4hYxRLi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_js7wLJby, HV_BINOP_MULTIPLY, 1, m, &cBinop_js7wLJby_sendMessage);
}

void Heavy_WSTD_EQ::cVar_xbfRqYIB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8DxI5GUE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_F0lcTAyr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lklbC5fa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_HzdUFozX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ayZjoHKE_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Wlp6iXWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_QFSSDvYY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eblvbmvP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_07OTzmJD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_N0J0SCzx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_pTWhHgJR_sendMessage);
}

void Heavy_WSTD_EQ::cSend_lVrwpXOd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_j8asidhY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_gLmsyqG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9jTFKy0i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_5LMsBUA7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ttvWNK5K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_4McVhf0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WPHyYCDF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WPHyYCDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_989GPrnl, HV_BINOP_MULTIPLY, 1, m, &cBinop_989GPrnl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_989GPrnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_57TlineR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_57TlineR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5LMsBUA7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_8DxI5GUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qu4S5WVO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qu4S5WVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M7VRQEEd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O08wpw8R_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yb6X6oph_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_koUdFRSo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9QdQ79aQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nujA9Vhr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_W5jrbI5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fkfi1nQ9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_tel9uz70_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BtF9vtSc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_JklfyOO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CJd2suN5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_MfeLWJbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ruc1xKEH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_js7wLJby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UcZD0oZ4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_0trlCbVZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_F0lcTAyr, 0, m, &cVar_F0lcTAyr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lxNGbbc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wlp6iXWN, 1, m, &cVar_Wlp6iXWN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yb6X6oph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MfeLWJbe, HV_BINOP_MULTIPLY, 0, m, &cBinop_MfeLWJbe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_koUdFRSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JklfyOO1, HV_BINOP_MULTIPLY, 0, m, &cBinop_JklfyOO1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_M7VRQEEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_9QdQ79aQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tel9uz70, HV_BINOP_MULTIPLY, 0, m, &cBinop_tel9uz70_sendMessage);
}

void Heavy_WSTD_EQ::cCast_nujA9Vhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W5jrbI5F, HV_BINOP_MULTIPLY, 0, m, &cBinop_W5jrbI5F_sendMessage);
}

void Heavy_WSTD_EQ::cCast_O08wpw8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_js7wLJby, HV_BINOP_MULTIPLY, 0, m, &cBinop_js7wLJby_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ayZjoHKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xbfRqYIB, 0, m, &cVar_xbfRqYIB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lklbC5fa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Wlp6iXWN, 0, m, &cVar_Wlp6iXWN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wIiluudP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zjFRVEfU, 1, m, &cIf_zjFRVEfU_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_DLtdlt7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_nY8oV2iA, m);
}

void Heavy_WSTD_EQ::cBinop_glGHbvMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DLtdlt7f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_z4oCwVhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zjFRVEfU, 0, m, &cIf_zjFRVEfU_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_fqQJ1CSm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xOYwOo8d, 0, m, &cSlice_xOYwOo8d_sendMessage);
      break;
    }
    default: {
      cSwitchcase_35b9Im70_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_xOYwOo8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Hc03UzDT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Hc03UzDT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_KidvNyaD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Hc03UzDT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Hc03UzDT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yNG4WYD5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_gFZafOdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rxHDCNB1_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_W4PTZWYJ, 0, m, &cIf_W4PTZWYJ_sendMessage);
}

void Heavy_WSTD_EQ::cIf_W4PTZWYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YkHx87AN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_7fk3U9T6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_8uwFjaIg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_hhtACbFR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_GBckknnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ctSDmxU, HV_BINOP_POW, 0, m, &cBinop_7ctSDmxU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7ctSDmxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rt7TjMTn, 0, m, &cIf_Rt7TjMTn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JuLDjXzs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Bq3ughep_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AwAGOPbw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7fk3U9T6, 0, m, &cIf_7fk3U9T6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AnNT5wPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pXT6eOi5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pXT6eOi5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7fk3U9T6, 1, m, &cIf_7fk3U9T6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hhtACbFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_JuLDjXzs_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8uwFjaIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Rt7TjMTn, 0, m, &cIf_Rt7TjMTn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Bq3ughep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ctSDmxU, HV_BINOP_POW, 1, m, &cBinop_7ctSDmxU_sendMessage);
  cMsg_GBckknnh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_Rt7TjMTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_wY564qPg, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_rxHDCNB1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_W4PTZWYJ, 1, m, &cIf_W4PTZWYJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YkHx87AN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WYbNvdgf, HV_BINOP_GREATER_THAN, 1, m, &cBinop_WYbNvdgf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Py3blVey, HV_BINOP_EQ, 1, m, &cBinop_Py3blVey_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ZT4uV8Y2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ddhTF2nL, HV_BINOP_ADD, 0, m, &cBinop_ddhTF2nL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ddhTF2nL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AnNT5wPM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AwAGOPbw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WYbNvdgf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rt7TjMTn, 1, m, &cIf_Rt7TjMTn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Py3blVey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xbTiHavL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_xbTiHavL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wY564qPg, m);
}

void Heavy_WSTD_EQ::cCast_RAYi1MUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZT4uV8Y2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_9DkiBzL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gFZafOdl, 0, m, &cVar_gFZafOdl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_o2wbwhxv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ddhTF2nL, HV_BINOP_ADD, 1, m, &cBinop_ddhTF2nL_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WYbNvdgf, HV_BINOP_GREATER_THAN, 0, m, &cBinop_WYbNvdgf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Py3blVey, HV_BINOP_EQ, 0, m, &cBinop_Py3blVey_sendMessage);
}

void Heavy_WSTD_EQ::cVar_SKMtx35j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8xdoIce8_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_q0en241i, 0, m, &cIf_q0en241i_sendMessage);
}

void Heavy_WSTD_EQ::cIf_q0en241i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_s2NbjQXs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_MLibaInc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_cVOZydDw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_YMbltdkp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_0Wa8WW84_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UOVGdAPN, HV_BINOP_POW, 0, m, &cBinop_UOVGdAPN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UOVGdAPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3f6Pb8fB, 0, m, &cIf_3f6Pb8fB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vgnSckwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_0F9BbzjS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_kCYQKkhk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yX4uMiYc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_tfpUPA6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MLibaInc, 0, m, &cIf_MLibaInc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yX4uMiYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MLibaInc, 1, m, &cIf_MLibaInc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YMbltdkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_vgnSckwy_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_cVOZydDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_3f6Pb8fB, 0, m, &cIf_3f6Pb8fB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0F9BbzjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UOVGdAPN, HV_BINOP_POW, 1, m, &cBinop_UOVGdAPN_sendMessage);
  cMsg_0Wa8WW84_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_3f6Pb8fB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HXZusjfJ_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AvLrJvYP_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_NRv8x9Cs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_8xdoIce8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q0en241i, 1, m, &cIf_q0en241i_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_s2NbjQXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eF29l7OF, HV_BINOP_GREATER_THAN, 1, m, &cBinop_eF29l7OF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CqX6ZbIG, HV_BINOP_EQ, 1, m, &cBinop_CqX6ZbIG_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_2AaIk6oj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Boj75aoH, HV_BINOP_ADD, 0, m, &cBinop_Boj75aoH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Boj75aoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kCYQKkhk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tfpUPA6N_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eF29l7OF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3f6Pb8fB, 1, m, &cIf_3f6Pb8fB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CqX6ZbIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PpIQ8Jx1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_PpIQ8Jx1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_HXZusjfJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AvLrJvYP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_NRv8x9Cs_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Mq8ksIPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SKMtx35j, 0, m, &cVar_SKMtx35j_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1t4jduV1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Boj75aoH, HV_BINOP_ADD, 1, m, &cBinop_Boj75aoH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eF29l7OF, HV_BINOP_GREATER_THAN, 0, m, &cBinop_eF29l7OF_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CqX6ZbIG, HV_BINOP_EQ, 0, m, &cBinop_CqX6ZbIG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QTOQgIER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2AaIk6oj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_1MklJSB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_PjVmlBnD_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_0fOC3rn1, 0, m, &cIf_0fOC3rn1_sendMessage);
}

void Heavy_WSTD_EQ::cIf_0fOC3rn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_yjuo7DLt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_N5xyGVUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_C24kizb4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_3WhPqvkp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_HiMeP1SV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ycpGkJJM, HV_BINOP_POW, 0, m, &cBinop_ycpGkJJM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ycpGkJJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XyW3LIt5, 0, m, &cIf_XyW3LIt5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_O1GuoVF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_jrqoj0Xf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lxDFv0n3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N5xyGVUl, 0, m, &cIf_N5xyGVUl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ABttLuNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_mD9Vep9Q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mD9Vep9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N5xyGVUl, 1, m, &cIf_N5xyGVUl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3WhPqvkp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_O1GuoVF4_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_C24kizb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_XyW3LIt5, 0, m, &cIf_XyW3LIt5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jrqoj0Xf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ycpGkJJM, HV_BINOP_POW, 1, m, &cBinop_ycpGkJJM_sendMessage);
  cMsg_HiMeP1SV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_XyW3LIt5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_G6O1Nrgj, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_PjVmlBnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0fOC3rn1, 1, m, &cIf_0fOC3rn1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yjuo7DLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vxc37eMM, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Vxc37eMM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_v7gazb9g, HV_BINOP_EQ, 1, m, &cBinop_v7gazb9g_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_PaAM7Cj1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gqfIyji9, HV_BINOP_ADD, 0, m, &cBinop_gqfIyji9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gqfIyji9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ABttLuNj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lxDFv0n3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Vxc37eMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XyW3LIt5, 1, m, &cIf_XyW3LIt5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_v7gazb9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_slYsI4D7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_slYsI4D7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_G6O1Nrgj, m);
}

void Heavy_WSTD_EQ::cCast_zTBO4QG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PaAM7Cj1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_jiFdvvUz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gqfIyji9, HV_BINOP_ADD, 1, m, &cBinop_gqfIyji9_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Vxc37eMM, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Vxc37eMM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_v7gazb9g, HV_BINOP_EQ, 0, m, &cBinop_v7gazb9g_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QQD0zvM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1MklJSB2, 0, m, &cVar_1MklJSB2_sendMessage);
}

void Heavy_WSTD_EQ::cIf_XqaMtaaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_5C0Ym30c, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_TvWtR1MO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_aEJYfduj, 0, m, &cSlice_aEJYfduj_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zExoFbLX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_aEJYfduj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aulUrHby_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aulUrHby_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_fn6yizAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aulUrHby_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_aulUrHby_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XkfBpn8X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_zExoFbLX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pMoz4XKd, 0, m, &cSlice_pMoz4XKd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_fqQJ1CSm_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_pMoz4XKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WTJ4cPdd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WTJ4cPdd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_wBWLGulE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WTJ4cPdd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_WTJ4cPdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_e64Qx61G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_35b9Im70_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xbpLVNjP, 0, m, &cSlice_xbpLVNjP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Iw8G4ART_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_xbpLVNjP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_z9kPpqqn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_z9kPpqqn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_aak4CMLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_z9kPpqqn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_z9kPpqqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ss85hQBr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_Iw8G4ART_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qKRwxHPa, 0, m, &cSlice_qKRwxHPa_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_qKRwxHPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HhJhNPXm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HhJhNPXm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_4WK0mqLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HhJhNPXm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_HhJhNPXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PWdMmHzd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Se8ae0ky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3avMmArf, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_P8lpwRy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LpFBQGgW, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_qHQGikCN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mJiwoo2r, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_0WvwETIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eNrooVM3, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_FLgVqXgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hOZtJvAw, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_mKhdWlKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gzqnlN7a_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_gzqnlN7a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kb6XA1Wt, HV_BINOP_DIVIDE, 1, m, &cBinop_Kb6XA1Wt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rgFGUHI4_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_iu6oM3QX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_sgUxyd4a_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_wRjnWGm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_iu6oM3QX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sgUxyd4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kb6XA1Wt, HV_BINOP_DIVIDE, 0, m, &cBinop_Kb6XA1Wt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rgFGUHI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wRjnWGm8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Kb6XA1Wt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p2tYIZ1R, HV_BINOP_MULTIPLY, 1, m, &cBinop_p2tYIZ1R_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_p2tYIZ1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bAxiRovL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BF9BCsAf_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_p0de4D55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CIq7zeNC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_IM2WReEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VTHTBtgz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_8iM2kOm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_V1fltldE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_V1fltldE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p2tYIZ1R, HV_BINOP_MULTIPLY, 0, m, &cBinop_p2tYIZ1R_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lo27Kg3b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_9eWDhaLu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9eWDhaLu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gIgN5Geh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_EfOZpjwr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4bHbXLaQ, 1, m, &cVar_4bHbXLaQ_sendMessage);
}

void Heavy_WSTD_EQ::cVar_4bHbXLaQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DsCfbAwS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_jHbW07hv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V1y7oiOL, HV_BINOP_MULTIPLY, 1, m, &cBinop_V1y7oiOL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SWYmjATR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_jHbW07hv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6gMrCr4w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TolrXJzL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TolrXJzL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VUtT2w2i, HV_BINOP_MULTIPLY, 1, m, &cBinop_VUtT2w2i_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_R70Zapxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yZBXIPVt, HV_BINOP_MULTIPLY, 1, m, &cBinop_yZBXIPVt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_BO4IGdXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_R70Zapxt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VyufPNEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bpmz1gwD, HV_BINOP_MULTIPLY, 1, m, &cBinop_Bpmz1gwD_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_RQJI7Lus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YqzCSnBi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YqzCSnBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H8fXwPqG, HV_BINOP_MULTIPLY, 1, m, &cBinop_H8fXwPqG_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Zh3y56Fd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7TiQXOnN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_8iM2kOm6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q3VBFUUM_sendMessage);
}

void Heavy_WSTD_EQ::cVar_tkggtXxX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_lo27Kg3b_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bAxiRovL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_p0de4D55_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BF9BCsAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_IM2WReEr_sendMessage);
}

void Heavy_WSTD_EQ::cSend_CIq7zeNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LL8CZACV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_VTHTBtgz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lutEfvGS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_G5Jn0DFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xpos8E3d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_gIgN5Geh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_meCjBfHS_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_meCjBfHS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QO2u9eel, HV_BINOP_MULTIPLY, 1, m, &cBinop_QO2u9eel_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QO2u9eel_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ieS5lLFC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ieS5lLFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_G5Jn0DFQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_DsCfbAwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XcD3cal7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XcD3cal7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c2cuyYIw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3K5fVUhg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5ihYrVz9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v331Mt8x_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AirlDwlb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_W3PHzd3s_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_V1y7oiOL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Se8ae0ky_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_VUtT2w2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P8lpwRy4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_yZBXIPVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qHQGikCN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Bpmz1gwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0WvwETIu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_H8fXwPqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FLgVqXgF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_9T5iytud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Zh3y56Fd, 0, m, &cVar_Zh3y56Fd_sendMessage);
}

void Heavy_WSTD_EQ::cCast_503zjIsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tkggtXxX, 1, m, &cVar_tkggtXxX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_c2cuyYIw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_W3PHzd3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V1y7oiOL, HV_BINOP_MULTIPLY, 0, m, &cBinop_V1y7oiOL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_AirlDwlb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VUtT2w2i, HV_BINOP_MULTIPLY, 0, m, &cBinop_VUtT2w2i_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5ihYrVz9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Bpmz1gwD, HV_BINOP_MULTIPLY, 0, m, &cBinop_Bpmz1gwD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_v331Mt8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yZBXIPVt, HV_BINOP_MULTIPLY, 0, m, &cBinop_yZBXIPVt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_3K5fVUhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_H8fXwPqG, HV_BINOP_MULTIPLY, 0, m, &cBinop_H8fXwPqG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7TiQXOnN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tkggtXxX, 0, m, &cVar_tkggtXxX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Q3VBFUUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4bHbXLaQ, 0, m, &cVar_4bHbXLaQ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_NS1pdeRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5uzwBRqX, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_auWwTonf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_O02kYo6Y, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_g0pagqdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BbZoOUuV, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_RNSHYlB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BszWr8sb, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_BZyK8ojP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Kmy4AW44_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_Kmy4AW44_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OPWAlESW, HV_BINOP_DIVIDE, 1, m, &cBinop_OPWAlESW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oyGNeEZf_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_7UUXylwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_SApvVf7s_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Xw5ZJR0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_7UUXylwF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SApvVf7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OPWAlESW, HV_BINOP_DIVIDE, 0, m, &cBinop_OPWAlESW_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oyGNeEZf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Xw5ZJR0P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_OPWAlESW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mITVhGNK, HV_BINOP_MULTIPLY, 1, m, &cBinop_mITVhGNK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mITVhGNK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JEZRepEm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1YpFw4H0_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_ITG29NwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XthXLilf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_DhoL365f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GZdanwP8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Fh2MiVvX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_yRSpgA8J_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yRSpgA8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mITVhGNK, HV_BINOP_MULTIPLY, 0, m, &cBinop_mITVhGNK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8s17cltr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_kIKoZz3P_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kIKoZz3P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UqXZ4aEv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_tfgT9QUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5wz3Ptf5, HV_BINOP_MULTIPLY, 1, m, &cBinop_5wz3Ptf5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hLaM5Prh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gCvuXMqq, 1, m, &cVar_gCvuXMqq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YZHd8BwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iNroQELg, HV_BINOP_MULTIPLY, 1, m, &cBinop_iNroQELg_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_6yOwNvNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pZVINLc5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pZVINLc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tRrkvROi, HV_BINOP_MULTIPLY, 1, m, &cBinop_tRrkvROi_sendMessage);
}

void Heavy_WSTD_EQ::cVar_gCvuXMqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DCnPnmYP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_UFWi8QIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eRwZV3zT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Fh2MiVvX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_exiKbq7F_sendMessage);
}

void Heavy_WSTD_EQ::cVar_8JvfzCZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_8s17cltr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JEZRepEm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ITG29NwT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1YpFw4H0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_DhoL365f_sendMessage);
}

void Heavy_WSTD_EQ::cSend_XthXLilf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ah7KPUEQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_GZdanwP8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_61QTNAwo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_6OSjkJLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qiwl3uw7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_UqXZ4aEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_ujfdt8wO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ujfdt8wO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7NfDegZ6, HV_BINOP_MULTIPLY, 1, m, &cBinop_7NfDegZ6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7NfDegZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SjzUgJGo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SjzUgJGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6OSjkJLy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_DCnPnmYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_WJiu4BV5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WJiu4BV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BuSiujEN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DtQHPy9c_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_C2eBVYLf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wx8KA5nz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bBeTpKOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NS1pdeRZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_5wz3Ptf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_auWwTonf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_iNroQELg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g0pagqdf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_tRrkvROi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RNSHYlB0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_t9Sgx8LZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UFWi8QIC, 0, m, &cVar_UFWi8QIC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OBoTch4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8JvfzCZ4, 1, m, &cVar_8JvfzCZ4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_exiKbq7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gCvuXMqq, 0, m, &cVar_gCvuXMqq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eRwZV3zT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8JvfzCZ4, 0, m, &cVar_8JvfzCZ4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DtQHPy9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iNroQELg, HV_BINOP_MULTIPLY, 0, m, &cBinop_iNroQELg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wx8KA5nz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bBeTpKOT, HV_BINOP_MULTIPLY, 0, m, &cBinop_bBeTpKOT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_C2eBVYLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5wz3Ptf5, HV_BINOP_MULTIPLY, 0, m, &cBinop_5wz3Ptf5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BuSiujEN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tRrkvROi, HV_BINOP_MULTIPLY, 0, m, &cBinop_tRrkvROi_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_hcpVi1mD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n3i9fv4Z, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_NsMfosMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lHdEctmj, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_WEXBTTy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uBmcKOCS, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_kr3KL4yg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_00CE6qrS, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Fw2BLTyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I9inOEZZ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_RSUubSPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MS5LYURr_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_MS5LYURr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z11vtAK5, HV_BINOP_DIVIDE, 1, m, &cBinop_Z11vtAK5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9JmKIBL2_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_WTvOqKdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_oe5WCQBA_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_72qgDGx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_WTvOqKdt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oe5WCQBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Z11vtAK5, HV_BINOP_DIVIDE, 0, m, &cBinop_Z11vtAK5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9JmKIBL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_72qgDGx9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Z11vtAK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kcTqbeuc, HV_BINOP_MULTIPLY, 1, m, &cBinop_kcTqbeuc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kcTqbeuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2Gz4Va0h_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yW3Vyfsg_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_aGmsWD4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kVGgyJ2d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_7JnfDOAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5uxrc3D1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_gxXIw6Ft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_eWvEeciI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eWvEeciI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_kcTqbeuc, HV_BINOP_MULTIPLY, 0, m, &cBinop_kcTqbeuc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xBQ54wf7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_kXMEpoNv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kXMEpoNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MqQA2J7Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_zeI0YxN4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vdOSbLl3, HV_BINOP_MULTIPLY, 1, m, &cBinop_vdOSbLl3_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_bZxtUmvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_N5Ry2SR3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_N5Ry2SR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zeI0YxN4_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_vYOtyo3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7RckqJB2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7RckqJB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2m6ciMGj, HV_BINOP_MULTIPLY, 1, m, &cBinop_2m6ciMGj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5bbrmsS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YLCs2jlz, HV_BINOP_MULTIPLY, 1, m, &cBinop_YLCs2jlz_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_j2UtQ1as_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NpMcn6b3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NpMcn6b3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5bbrmsS1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xJvvB3Oo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xiwsHefm, 1, m, &cVar_xiwsHefm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_G1fAxiTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wcO2ai0P, HV_BINOP_MULTIPLY, 1, m, &cBinop_wcO2ai0P_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_2r2OTeCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Q1hqQk25_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Q1hqQk25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cyL6EpDN, HV_BINOP_MULTIPLY, 1, m, &cBinop_cyL6EpDN_sendMessage);
}

void Heavy_WSTD_EQ::cVar_xiwsHefm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BLV5nMhK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_vzw5CR0U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oY70DIyU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_gxXIw6Ft_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gFkaAWYA_sendMessage);
}

void Heavy_WSTD_EQ::cVar_awQgZzb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_xBQ54wf7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yW3Vyfsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_7JnfDOAL_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2Gz4Va0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_aGmsWD4S_sendMessage);
}

void Heavy_WSTD_EQ::cSend_kVGgyJ2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_6dljYM9J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_5uxrc3D1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dismy5a8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_fAqlrclp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_INBWazm2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_MqQA2J7Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2OlfAyLm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2OlfAyLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JvRDfOQ2, HV_BINOP_MULTIPLY, 1, m, &cBinop_JvRDfOQ2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JvRDfOQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_geL4CgxF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_geL4CgxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fAqlrclp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_BLV5nMhK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_avBOLBh0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_avBOLBh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2VATFCD5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_USX1JnQG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qqUa9Gtr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8qcCMti2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hhJfxl6T_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mNUWWZOH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vdOSbLl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hcpVi1mD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_2m6ciMGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NsMfosMP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_YLCs2jlz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WEXBTTy8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_wcO2ai0P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kr3KL4yg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_cyL6EpDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fw2BLTyn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_cNPFHER9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_awQgZzb1, 1, m, &cVar_awQgZzb1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_VnZ8UJHi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vzw5CR0U, 0, m, &cVar_vzw5CR0U_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mNUWWZOH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vdOSbLl3, HV_BINOP_MULTIPLY, 0, m, &cBinop_vdOSbLl3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8qcCMti2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YLCs2jlz, HV_BINOP_MULTIPLY, 0, m, &cBinop_YLCs2jlz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hhJfxl6T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2m6ciMGj, HV_BINOP_MULTIPLY, 0, m, &cBinop_2m6ciMGj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qqUa9Gtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wcO2ai0P, HV_BINOP_MULTIPLY, 0, m, &cBinop_wcO2ai0P_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2VATFCD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_USX1JnQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cyL6EpDN, HV_BINOP_MULTIPLY, 0, m, &cBinop_cyL6EpDN_sendMessage);
}

void Heavy_WSTD_EQ::cCast_oY70DIyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_awQgZzb1, 0, m, &cVar_awQgZzb1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gFkaAWYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xiwsHefm, 0, m, &cVar_xiwsHefm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HXZusjfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XqaMtaaH, 1, m, &cIf_XqaMtaaH_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_1HZJ3plV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_5C0Ym30c, m);
}

void Heavy_WSTD_EQ::cBinop_AvLrJvYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1HZJ3plV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_NRv8x9Cs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XqaMtaaH, 0, m, &cIf_XqaMtaaH_sendMessage);
}

void Heavy_WSTD_EQ::cVar_WXZBWiDm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gQ5uc0So, HV_BINOP_DIVIDE, 0, m, &cBinop_gQ5uc0So_sendMessage);
}

void Heavy_WSTD_EQ::cVar_CynyOav2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zi8QLL5u, HV_BINOP_DIVIDE, 1, m, &cBinop_zi8QLL5u_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_gQ5uc0So, HV_BINOP_DIVIDE, 1, m, &cBinop_gQ5uc0So_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_0GiB36YJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hcyvxBdi, HV_BINOP_DIVIDE, 0, m, &cBinop_hcyvxBdi_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_4jdAYLIb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hcyvxBdi, HV_BINOP_DIVIDE, 1, m, &cBinop_hcyvxBdi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CDOUGRqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zi8QLL5u, HV_BINOP_DIVIDE, 0, m, &cBinop_zi8QLL5u_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IpR81aCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CynyOav2, 0, m, &cVar_CynyOav2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fAS4vuX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WXZBWiDm, 0, m, &cVar_WXZBWiDm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zi8QLL5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_0GiB36YJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gQ5uc0So_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_4jdAYLIb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hcyvxBdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ab1MBNp2_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_3LVxDxek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_ivJUJaQ6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NSK7JRC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_Z9ikRXFn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ab1MBNp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NSK7JRC8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Z9ikRXFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_3LVxDxek_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ivJUJaQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9wifXj20_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ecvRDOvq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4rctmv0a_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_TvWtR1MO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_wSsM5OnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4rctmv0a_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_TvWtR1MO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_JYxt0HWn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4rctmv0a_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_TvWtR1MO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_sztrVgAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4rctmv0a_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_TvWtR1MO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_9wifXj20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_4rctmv0a_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_TvWtR1MO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_wnXrQNXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_1aBWMhMN, 0, m, &cVar_1aBWMhMN_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_3HwgGvPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_dsN8pkgu, 0, m, &cVar_dsN8pkgu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JADpV1aH, 0, m, &cVar_JADpV1aH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kvGWOCty, 0, m, &cVar_kvGWOCty_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_CxZB78YB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dsN8pkgu, 0, m, &cVar_dsN8pkgu_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_FL9dNFWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JADpV1aH, 0, m, &cVar_JADpV1aH_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_E98oWkT5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kvGWOCty, 0, m, &cVar_kvGWOCty_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_hK32FfeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CrZRwEdo, 0, m, &cVar_CrZRwEdo_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_61aDsS7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mw5sswZO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KuiEuRjc_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_JuQYGT0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1WO6phaX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d0powlEg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NoPA3ptx_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_6EXhVNgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jDpKHe6X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WLKBPtO8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UzvBgY0O_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_CTK1nFOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iaqoXGhL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3DPqSU0P_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oSy4fS3Z_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Hj8M30AB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UngnOGwE_sendMessage(_c, 0, m);
  cMsg_cn3zdHj9_sendMessage(_c, 0, m);
  cMsg_r7SZ1GKx_sendMessage(_c, 0, m);
  cMsg_mKhdWlKz_sendMessage(_c, 0, m);
  cMsg_BZyK8ojP_sendMessage(_c, 0, m);
  cMsg_RSUubSPI_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_F3TGriMZ, 0, m, &cVar_F3TGriMZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CrZRwEdo, 0, m, &cVar_CrZRwEdo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_F0lcTAyr, 0, m, &cVar_F0lcTAyr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Zh3y56Fd, 0, m, &cVar_Zh3y56Fd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UFWi8QIC, 0, m, &cVar_UFWi8QIC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vzw5CR0U, 0, m, &cVar_vzw5CR0U_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wf06aHRM, 0, m, &cVar_wf06aHRM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gf4T7K3Q, 0, m, &cVar_gf4T7K3Q_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_71BrfrCC, 0, m, &cVar_71BrfrCC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8L6MRkm5, 0, m, &cVar_8L6MRkm5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_K1Pp0HtM, 0, m, &cVar_K1Pp0HtM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bMIl5PfJ, 0, m, &cVar_bMIl5PfJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HBBtyO8s, 0, m, &cVar_HBBtyO8s_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_x3LUnzeW, 0, m, &cVar_x3LUnzeW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KidvNyaD, 0, m, &cVar_KidvNyaD_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_gFZafOdl, 0, m, &cVar_gFZafOdl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SKMtx35j, 0, m, &cVar_SKMtx35j_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1MklJSB2, 0, m, &cVar_1MklJSB2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fn6yizAB, 0, m, &cVar_fn6yizAB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wBWLGulE, 0, m, &cVar_wBWLGulE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aak4CMLg, 0, m, &cVar_aak4CMLg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4WK0mqLM, 0, m, &cVar_4WK0mqLM_sendMessage);
  cMsg_3HwgGvPt_sendMessage(_c, 0, m);
  cMsg_wnXrQNXa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_NeF5E0XD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YjgcDy7q, HV_BINOP_MULTIPLY, 0, m, &cBinop_YjgcDy7q_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Nmbe8yW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6Dh5MAKq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6Tf7xrse_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KBLdL1xI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ij7lfmdn_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_KZTT3m08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1dIvgceH_sendMessage);
  cMsg_MdLD9Ptp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_ekk0F6qf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VPmkB56d, HV_BINOP_MULTIPLY, 0, m, &cBinop_VPmkB56d_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_7vxng0Me_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_G41EKEDu_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_mdVnO129_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OKu7lXxe, HV_BINOP_MULTIPLY, 1, m, &cBinop_OKu7lXxe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_aXUv7mOd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_jdf2ETPe_sendMessage);
  cMsg_GZeLxtxa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_j8asidhY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_989GPrnl, HV_BINOP_MULTIPLY, 0, m, &cBinop_989GPrnl_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_9jTFKy0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CXsN8PNP_sendMessage(_c, 0, m);
  cMsg_lWvAI4JD_sendMessage(_c, 0, m);
  cMsg_16PfvYlA_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_yhMWdz8l_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_ttvWNK5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_JWLu63nu_sendMessage);
  cMsg_DRsrN7z7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_yNG4WYD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UFWi8QIC, 0, m, &cVar_UFWi8QIC_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_PWdMmHzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OBoTch4C_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t9Sgx8LZ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_XkfBpn8X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9DkiBzL8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o2wbwhxv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RAYi1MUP_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Ss85hQBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QQD0zvM6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jiFdvvUz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zTBO4QG3_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_e64Qx61G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mq8ksIPr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1t4jduV1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QTOQgIER_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_LL8CZACV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QO2u9eel, HV_BINOP_MULTIPLY, 0, m, &cBinop_QO2u9eel_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_lutEfvGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_SWYmjATR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6gMrCr4w_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_BO4IGdXG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_VyufPNEE_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_xpos8E3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_EfOZpjwr_sendMessage);
  cMsg_RQJI7Lus_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_Ah7KPUEQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7NfDegZ6, HV_BINOP_MULTIPLY, 0, m, &cBinop_7NfDegZ6_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_61QTNAwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_YZHd8BwN_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_qiwl3uw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bBeTpKOT, HV_BINOP_MULTIPLY, 1, m, &cBinop_bBeTpKOT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_tfgT9QUO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_hLaM5Prh_sendMessage);
  cMsg_6yOwNvNS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_6dljYM9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JvRDfOQ2, HV_BINOP_MULTIPLY, 0, m, &cBinop_JvRDfOQ2_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_dismy5a8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bZxtUmvi_sendMessage(_c, 0, m);
  cMsg_vYOtyo3t_sendMessage(_c, 0, m);
  cMsg_j2UtQ1as_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_G1fAxiTd_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_INBWazm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xJvvB3Oo_sendMessage);
  cMsg_2r2OTeCz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_I4t9GnMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1aBWMhMN, 0, m, &cVar_1aBWMhMN_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_YvhMMD4q, VOf(Bf0));
    __hv_varread_f(&sVarf_mW5jFCoy, VOf(Bf1));
    __hv_varread_f(&sVarf_4v767zBG, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_sxOnOyUB, VOf(Bf0));
    __hv_varread_f(&sVarf_Cz6azwi8, VOf(Bf1));
    __hv_varread_f(&sVarf_a88uIjhL, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_26RVCf28, VOf(Bf0));
    __hv_line_f(&sLine_KyVLa1UB, VOf(Bf1));
    __hv_line_f(&sLine_7nRYMCXn, VOf(Bf4));
    __hv_line_f(&sLine_YGe39g7z, VOf(Bf5));
    __hv_line_f(&sLine_9pQcRCGk, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_EplGjzsd, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_d5kWGl8E, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_Fp9h5P4u, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_vOIdAb0w, VOf(Bf1));
    __hv_line_f(&sLine_uQUaTdyF, VOf(Bf0));
    __hv_line_f(&sLine_CJZa2lb7, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_xi38GoFM, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_nY8oV2iA, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_u1zEhbnB, VOf(Bf7));
    __hv_line_f(&sLine_ypbWiiaM, VOf(Bf1));
    __hv_line_f(&sLine_bWKx1Kb5, VOf(Bf4));
    __hv_line_f(&sLine_EoWDm78S, VOf(Bf6));
    __hv_line_f(&sLine_5q0WqqtD, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_EIDJ9JG5, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_tlMz0CMM, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_YvhMMD4q, VIf(Bf5));
    __hv_varwrite_f(&sVarf_mW5jFCoy, VIf(Bf0));
    __hv_varwrite_f(&sVarf_4v767zBG, VIf(Bf6));
    __hv_line_f(&sLine_3avMmArf, VOf(Bf6));
    __hv_line_f(&sLine_LpFBQGgW, VOf(Bf0));
    __hv_line_f(&sLine_mJiwoo2r, VOf(Bf5));
    __hv_line_f(&sLine_eNrooVM3, VOf(Bf8));
    __hv_line_f(&sLine_hOZtJvAw, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_sxZPvPz9, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_wY564qPg, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_5uzwBRqX, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_O02kYo6Y, VOf(Bf0));
    __hv_line_f(&sLine_BbZoOUuV, VOf(Bf6));
    __hv_line_f(&sLine_BszWr8sb, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_1lqnmFQd, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_5C0Ym30c, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_n3i9fv4Z, VOf(Bf1));
    __hv_line_f(&sLine_lHdEctmj, VOf(Bf0));
    __hv_line_f(&sLine_uBmcKOCS, VOf(Bf5));
    __hv_line_f(&sLine_00CE6qrS, VOf(Bf4));
    __hv_line_f(&sLine_I9inOEZZ, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_fVVEeYHk, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_G6O1Nrgj, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_sxOnOyUB, VIf(Bf8));
    __hv_varwrite_f(&sVarf_Cz6azwi8, VIf(Bf6));
    __hv_varwrite_f(&sVarf_a88uIjhL, VIf(Bf4));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
